import React from 'react';
import { visualizationColors } from 'config';
import { Popover, PopoverTrigger, PopoverContent } from '@graphpolaris/shared/lib/components/layout/Popover';

const hexToRgb = (hex: string): [number, number, number] => {
  const r = parseInt(hex.slice(1, 3), 16);
  const g = parseInt(hex.slice(3, 5), 16);
  const b = parseInt(hex.slice(5, 7), 16);
  return [r, g, b];
};

type Props = {
  value: [number, number, number];
  onChange: (val: [number, number, number]) => void;
};

export function ColorPicker({ value, onChange }: Props) {
  return (
    value && (
      <div>
        <Popover>
          <PopoverTrigger
            onClick={(e) => {
              e.stopPropagation();
            }}
          >
            <div className="w-4 h-4 rounded-sm" style={{ backgroundColor: `rgb(${value[0]}, ${value[1]}, ${value[2]})` }} />
          </PopoverTrigger>
          <PopoverContent>
            <div
              className="grid grid-cols-4 gap-2 p-2"
              onClick={(e) => {
                e.stopPropagation();
              }}
            >
              {visualizationColors.GPCat.colors[14].map((hexColor) => {
                const [r, g, b] = hexToRgb(hexColor);
                return (
                  <div
                    key={hexColor}
                    className="w-4 h-4 rounded-sm cursor-pointer"
                    style={{ backgroundColor: hexColor }}
                    onClick={(e) => {
                      e.stopPropagation();
                      onChange([r, g, b]);
                    }}
                  />
                );
              })}
            </div>
          </PopoverContent>
        </Popover>
      </div>
    )
  );
}
